# Калькулятор с багами

Это приложение создано для тестов в режиме чёрного ящика.

## Как установить и запустить

> [!NOTE]
> Для работы приложения требуется Python версии 3.9 или выше.

Установить калькулятор можно с помощью pip. Для этого в терминале введите команду:
```shell
pip install "calc-with-bugs==0.1.0"
```

Чтобы запустить в терминале введите команду:

```shell
python -m calc
```

## Какие есть баги

- Можно ввести буквы в окошко, это крашит приложение
- Кнопка MC (Memory clear) отключена
- Нажмите на 0)
- Нажмите на MR)
- кнопка стирания не работает